const ROUTE = 'http://34.70.36.158';
const PORT = '8080';

// State management
let currentSort, currentTarget;
let isFetching = false;
const button = document.getElementById("refreshBtn");
const form = document.getElementById("filterControl");
const title = document.getElementById("pageTitle");
const wishTitle = "Top 3 wishlists with the highest total purchase amount";
const itemTitle = "Top 3 most expensive purchased items";
const trItem = document.getElementById("itemsTable");
const trWish = document.getElementById("wishlistsTable");

// Initialize from URL
function initFromUrl() {
    const path = window.location.pathname;
    const segments = path.split("/").filter(segment => segment !== "");
    currentSort = segments[segments.length - 1];
    currentTarget = segments[segments.length - 2];
}

// Main data loading function
async function fetchData() {
    let url = '';
    if (currentTarget === 'items') {
        url = `${ROUTE}:${PORT}/items?sortBy=price&sort=${currentSort}&onlyBought=true`;
    } else {
        url = `${ROUTE}:${PORT}/wishLists/sortedByTotalBought?sort=${currentSort}`;
    }

    try {
        const response = await fetch(url);
        const data = await response.json();
        
        // Populate table based on target
        const tableBody = document.getElementById('dataBody');
        tableBody.innerHTML = '';
        
        const itemsToDisplay = currentTarget === 'wishlists' ? data.wishLists : data.items;
        populateTable(itemsToDisplay);

        title.innerText = currentTarget === "wishlists" ? wishTitle : itemTitle;

        if (currentTarget === "wishlists") {
            trItem.hidden = true;
            trWish.hidden = false;
        } else {
            trWish.hidden = true;
            trItem.hidden = false;
        }
        
    } catch (error) {
        console.error('Error fetching data:', error);
    } finally {
        isFetching = false;
        button.disabled = false;
    }
}

// Table population
function populateTable(data) {
    const tableBody = document.getElementById('dataBody');

    data.forEach(key => {
        const row = document.createElement('tr');
        
        if (currentTarget === 'items') {
            row.innerHTML = `
                <td>${key.id}</td>
                <td>${key.title}</td>
                <td>${key.description}</td>
                <td>${key.price}</td>
                <td>${key.wishList.name}</td>
                <td class="active">${key.wishList.isActive ? 'Active' : 'Unactive'}</td>
                <td>${key.wishList.createdAt}</td>
                <td>${key.wishList.expirationDate}</td>
                <td>${key.wishList.user.username}</td>
            `;
        } else {
            row.innerHTML = `
                <td>${key.wishList.id}</td>
                <td>${key.wishList.name}</td>
                <td>${key.wishList.description}</td>
                <td>${key.totalPrice}</td>
                <td>
                    <span class="${key.isActive ? 'active' : 'inactive'}">
                        ${key.isActive ? 'Active' : 'Inactive'}
                    </span>
                </td>
                <td>${key.wishList.user.username}</td>
                <td>${key.wishList.createdAt}</td>
                <td>${key.wishList.expirationDate}</td>
            `;
        }

        tableBody.appendChild(row);
    });
}

// Controlled data loading
function loadData() {
    if (isFetching) return;
    
    isFetching = true;
    button.disabled = true;
    fetchData();
}

// Form submission handler
form.addEventListener("submit", function(event) {
    event.preventDefault();
    
    currentSort = document.getElementById('sort').value;
    currentTarget = document.getElementById('target').value;
    
    // Update URL without reload
    const newUrl = `/dashboard/insights/${currentTarget}/${currentSort}`;
    window.history.pushState({ path: newUrl }, '', newUrl);
    
    loadData();
});

// Handle browser navigation
window.addEventListener('popstate', () => {
    initFromUrl();
    loadData();
});

// Initial setup
initFromUrl();
loadData();